@@ -54,7 +54,9 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
+import java.io.ByteArrayInputStream;
 import java.io.IOException;
+import java.io.StringReader;
 import java.util.Iterator;
 import java.util.List;
 
@@ -283,7 +285,111 @@ public class DOMXPathTest extends TestCase
         assertEquals("d", result);
     }
     
+
+    public void testJaxen207() 
+      throws JaxenException {
+        XPath xpath = new DOMXPath( "contains($FinResp, \"NS_Payables_Associate\") or"
+                + "contains($FinResp, \"NS_Payables_Manager\") or"
+                + "contains($FinResp, \"NS_Payment_Processing\") or"
+                + "contains($FinResp, \"NS_Vendor_Maintenance\") or"
+                + "contains($FinResp, \"NS_IB_Receivables_Manager\") or"
+                + "contains($FinResp, \"NS_IB_Receivables_User\") or"
+                + "contains($FinResp, \"NS_Receivables_Manager\") or"
+                + "contains($FinResp, \"NS_Receivables_User\") or"
+                + "contains($FinResp, \"NS_Cash_Management_User\") or"
+                + "contains($FinResp, \"NS_Cost_Management\") or"
+                + "contains($FinResp, \"NS_Fixed_Assets_Manager\") or"
+                + "contains($FinResp, \"NS_Fixed_Asset_User\") or"
+                + "contains($FinResp, \"NS_General_Ledger_Inquiry\") or"
+                + "contains($FinResp, \"NS_General_Ledger_User\") or"
+                + "contains($FinResp, \"NS_General_Ledger_Supervisor\") or"
+                + "contains($FinResp, \"NS_IB_General_Ledger_User\") or"
+                + "contains($FinResp, \"NS_IB_Oracle_Web_ADI\") or"
+                + "contains($FinResp, \"NS_Oracle_Web_ADI\") or"
+         + "contains($FinResp, \"NS_CRM_Resource_Manager\") or"
+                + "contains($FinResp, \"NS_Distributor_Manager\") or"
+                + "contains($FinResp, \"NS_OIC_User\") or"
+                + "contains($FinResp, \" NS_Operations_Buyer\") or"
+                + "contains($FinResp, \"NS_Purchasing_Buyer\") or"
+                + "contains($FinResp, \"NS_Vendor_Maintenance\") or "
+              + "contains($FinResp, \"SL_Payables_Manager\") or"
+                + "contains($FinResp, \"SL_Payables_Super_User\") or"
+                + "contains($FinResp, \"SL_Payment_Processing\") or"
+                + "contains($FinResp, \"SL_Vendor_Maintenance\") or"
+                + "contains($InvResp, \"SL_Inventory_Super_User\") or"
+                         + "contains($FinResp, \"\") or"
+                + "contains($FinResp, \"SL_Receivables_Supervisor\") or"
+                + "contains($FinResp, \"SL_Receivables_User\") or"
+                + "contains($FinResp, \"NS_Cost_Management_Inquiry\") or"
+                + "contains($FinResp, \"SL_Fixed_Asset_User\") or"
+                + "contains($FinResp, \"SL_Fixed_Assets_Manager\") or"
+                + "contains($FinResp, \"SL_General_Ledger_Inquiry\") or"
+                + "contains($FinResp, \"SL_General_Ledger_Supervisor\") or"
+                + "contains($FinResp, \"SL_General_Ledger_User\") or"
+                + "contains($FinResp, \"SL_Oracle_Web_ADI\") or"
+                + "contains($FinResp, \"SL_Buyer\") or"
+                + "contains($FinResp, \"SL_Purchasing_Inquiry\") or"
+                + "contains($FinResp, \"SL_Payables_Manager\") or"
+                + "contains($FinResp, \"SL_Payables_Super_User\") or"
+                + "contains($FinResp, \"SL_Payment_Processing\") or"
+                + "contains($FinResp, \"SL_Vendor_Maintenance\") or"
+                + "contains($InvResp, \"SL_Inventory_Super_User\") or"
+                + "contains($FinResp, \"\") or"
+                + "contains($FinResp, \"SL_Receivables_Supervisor\") or"
+                + "contains($FinResp, \"SL_Receivables_User\") or"
+                + "contains($FinResp, \"NS_Cost_Management_Inquiry\") or"
+                + "contains($FinResp, \"SL_Fixed_Asset_User\") or"
+                + "contains($FinResp, \"SL_Fixed_Assets_Manager\") or"
+                + "contains($FinResp, \"SL_General_Ledger_Inquiry\") or"
+                + "contains($FinResp, \"SL_General_Ledger_Supervisor\") or"
+                + "contains($FinResp, \"SL_General_Ledger_User\") or"
+                + "contains($FinResp, \"SL_Oracle_Web_ADI\") or"
+                + "contains($FinResp, \"SL_Buyer\") or"
+                + "contains($FinResp, \"SL_Purchasing_Inquiry\")");
+    }
+
+
+    public void testImplictCastFromTextInARelationalExpression() 
+      throws JaxenException, ParserConfigurationException, SAXException, IOException {
+        XPath implicitCast = new DOMXPath("//lat[(text() >= 37)]");
+        XPath explicitCast = new DOMXPath("//lat[(number(text()) >= 37)]");
+        DocumentBuilder builder = factory.newDocumentBuilder();
+        ByteArrayInputStream in = new ByteArrayInputStream("<geo><lat>39</lat></geo>".getBytes("UTF-8"));
+        Document document = builder.parse(in);
+        List result = explicitCast.selectNodes(document);
+        assertEquals(1, result.size());
+        result = implicitCast.selectNodes(document);
+        assertEquals(1, result.size());
+    }
+    
      
+    public void testImplictCastFromCommentInARelationalExpression() 
+      throws JaxenException, ParserConfigurationException, SAXException, IOException {
+          XPath implicitCast = new DOMXPath("//lat[(comment() >= 37)]");
+          XPath explicitCast = new DOMXPath("//lat[(number(comment()) >= 37)]");
+          DocumentBuilder builder = factory.newDocumentBuilder();
+          ByteArrayInputStream in = new ByteArrayInputStream("<geo><lat><!--39--></lat></geo>".getBytes("UTF-8"));
+          Document document = builder.parse(in);
+          List result = explicitCast.selectNodes(document);
+          assertEquals(1, result.size());
+          result = implicitCast.selectNodes(document);
+          assertEquals(1, result.size());
+    }
+  
+
+    public void testImplictCastFromProcessingInstructionInARelationalExpression() 
+      throws JaxenException, ParserConfigurationException, SAXException, IOException {
+        XPath implicitCast = new DOMXPath("//lat[(processing-instruction() >= 37)]");
+        XPath explicitCast = new DOMXPath("//lat[(number(processing-instruction()) >= 37)]");
+        DocumentBuilder builder = factory.newDocumentBuilder();
+        ByteArrayInputStream in = new ByteArrayInputStream("<geo><lat><?test 39?></lat></geo>".getBytes("UTF-8"));
+        Document document = builder.parse(in);
+        List result = explicitCast.selectNodes(document);
+        assertEquals(1, result.size());
+        result = implicitCast.selectNodes(document);
+        assertEquals(1, result.size());
+    }
+    
     public void testPrecedingAxisInDocumentOrder() 
       throws JaxenException {
         
